# Table of Contents

- [obsolescence-risk-management-dashboard](<./obsolescence-risk-management-dashboard.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Obsolescence Risk Management Dashboard](<./Obsolescence-Risk-Management-Dashboard.md>)
  - [Overview](<./Obsolescence-Risk-Management-Dashboard/Overview.md>)
  - [Inclusion of Fact Sheets for Calculation](<./Obsolescence-Risk-Management-Dashboard/Inclusion-of-Fact-Sheets-for-Calculation.md>)
  - [Configurability of Dashboard Panels](<./Obsolescence-Risk-Management-Dashboard/Configurability-of-Dashboard-Panels.md>)
  - [Dashboard Panels](<./Obsolescence-Risk-Management-Dashboard/Dashboard-Panels.md>)
